@@ -48,12 +48,13 @@ def _export(dataset_input, dataset_output, random_index_column, path, column_nam
     if shuffle:
         shuffle_array = dataset_output.columns[random_index_column]
 
-    partial_shuffle = shuffle and len(dataset_input) != len(dataset_input)
+    partial_shuffle = shuffle and len(dataset_input) != N
 
     if partial_shuffle:
         # if we only export a portion, we need to create the full length random_index array, and
-        shuffle_array_full = np.zeros(len(dataset_input), dtype=byteorder + "i8")
-        vaex.vaexfast.shuffled_sequence(shuffle_array_full)
+        #shuffle_array_full = np.zeros(len(dataset_input), dtype=byteorder + "i8")
+        #vaex.vaexfast.shuffled_sequence(shuffle_array_full)
+        shuffle_array_full = np.random.choice(len(dataset_input), len(dataset_input), replace=False)
         # then take a section of it
         # shuffle_array[:] = shuffle_array_full[:N]
         shuffle_array[:] = shuffle_array_full[shuffle_array_full < N]
@@ -61,8 +62,9 @@ def _export(dataset_input, dataset_output, random_index_column, path, column_nam
         order_array = shuffle_array
     elif shuffle:
         # better to do this in memory
-        shuffle_array_memory = np.zeros_like(shuffle_array)
-        vaex.vaexfast.shuffled_sequence(shuffle_array_memory)
+        #shuffle_array_memory = np.zeros_like(shuffle_array)
+        # vaex.vaexfast.shuffled_sequence(shuffle_array_memory)
+        shuffle_array_memory = np.random.choice(N, N, replace=False)
         shuffle_array[:] = shuffle_array_memory
         order_array = shuffle_array
 
@@ -84,7 +86,7 @@ def _export(dataset_input, dataset_output, random_index_column, path, column_nam
     # i1, i2 = 0, N #len(dataset)
     # print "creating shuffled array"
     if progress == True:
-        progress = vaex.utils.progressbar_callable("exporting")
+        progress = vaex.utils.progressbar_callable(title="exporting")
     progress = progress or (lambda value: True)
     progress_total = len(column_names) * len(dataset_input)
     progress_value = 0
@@ -354,7 +356,7 @@ def main(argv):
                 row = 0
                 copy(line, row)
                 row += 1
-                progressbar = vaex.utils.progressbar("exporting") if args.progress else None
+                progressbar = vaex.utils.progressbar(title="exporting") if args.progress else None
                 for line in lines:
                     # print line
                     copy(line, row)
@@ -385,7 +387,7 @@ def main(argv):
             if not args.quiet:
                 print("exporting %d rows and %d columns" % (len(dataset), len(columns)))
                 print("columns: " + " ".join(columns))
-            progressbar = vaex.utils.progressbar("exporting") if args.progress else None
+            progressbar = vaex.utils.progressbar(title="exporting") if args.progress else None
 
             def update(p):
                 if progressbar:
